==> gnopernicus-0.3.1.tar.bz2: gnopernicus-0.3.1/speech/libsrs/spgscb.h <==
/* spgscb.h
 *
 * Copyright 2001, 2002 Sun Microsystems, Inc.,
 * Copyright 2001, 2002 BAUM Retec, A.G.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */
#ifndef _SPGSCB_H_
#define _SPGSCB_H_


#include <bonobo/bonobo-object.h>
#include <gnome-speech/GNOME_Speech_SynthesisDriver.h>


#define CALLBACK_TYPE        (callback_get_type ())
#define CALLBACK(o)          (G_TYPE_CHECK_INSTANCE_CAST ((o), CALLBACK_TYPE, CALLBACK))
#define CALLBACK_CLASS(k)    (G_TYPE_CHECK_CLASS_CAST((k), CALLBACK_TYPE, CallbackClass))
#define IS_CALLBACK(o)       (G_TYPE_CHECK_INSTANCE_TYPE ((o), CALLBACK_TYPE))
#define IS_CALLBACK_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), CALLBACK_TYPE))

typedef void (* GSCB)(int reason, gpointer user_data);

typedef struct 
{
    BonoboObject parent;
} Callback;

typedef struct 
{
  BonoboObjectClass 			parent_class;
  POA_GNOME_Speech_SpeechCallback__epv	epv;
} CallbackClass;

GType
callback_get_type (void);

Callback *
callback_new (gpointer	client_callback, 
	      gpointer	client_data);

#endif  /* _SPGSCB_H_ */

==> gnopernicus-0.9.5.tar.bz2: gnopernicus-0.9.5/speech/libsrs/spgscb.h <==
/* spgscb.h
 *
 * Copyright 2001, 2002 Sun Microsystems, Inc.,
 * Copyright 2001, 2002 BAUM Retec, A.G.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */
#ifndef _SPGSCB_H_
#define _SPGSCB_H_


#include <bonobo/bonobo-object.h>
#include <gnome-speech/gnome-speech.h>

#define CALLBACK_TYPE        (callback_get_type ())
#define CALLBACK(o)          (G_TYPE_CHECK_INSTANCE_CAST ((o), CALLBACK_TYPE, CALLBACK))
#define CALLBACK_CLASS(k)    (G_TYPE_CHECK_CLASS_CAST((k), CALLBACK_TYPE, CallbackClass))
#define IS_CALLBACK(o)       (G_TYPE_CHECK_INSTANCE_TYPE ((o), CALLBACK_TYPE))
#define IS_CALLBACK_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), CALLBACK_TYPE))

typedef void (* GSCB)(int reason, gpointer user_data);

typedef struct 
{
    BonoboObject parent;
} Callback;

typedef struct 
{
  BonoboObjectClass 			parent_class;
  POA_GNOME_Speech_SpeechCallback__epv	epv;
} CallbackClass;

GType
callback_get_type (void);

Callback *
callback_new (gpointer	client_callback, 
	      gpointer	client_data);

#endif  /* _SPGSCB_H_ */
